==> renew2.3source.zip: renew2.3/src/FS/src/de/renew/formalism/fs/ShadowConcept.java <==
package de.renew.formalism.fs;

import de.renew.shadow.ShadowInscribable;
import de.renew.shadow.ShadowNet;

import java.util.List;


public class ShadowConcept extends ShadowInscribable {
    private String namespace;
    private String name;
    private String approp;
    private String conceptDocumentation;
    private List<String> slotDocumentation;

    public ShadowConcept(ShadowNet net, String name, String approp,
                         String conceptDocumentation,
                         List<String> slotDocumentation) {
        super(net);
        int end = name.indexOf("::");
        if (end == -1) {
            namespace = net.getName();
            this.name = name;
        } else {
            namespace = name.substring(0, end);
            this.name = name.substring(end + 2);
        }
        this.approp = approp;
        this.conceptDocumentation = conceptDocumentation;
        this.slotDocumentation = slotDocumentation;
    }

    //  public void setName(String name) {
    //    this.name=name;
    //  }
    public String getName() {
        return name;
    }

    public String getNamespace() {
        return namespace;
    }

    public String getFullName() {
        return namespace + "::" + name;
    }

    public void setApprop(String approp) {
        this.approp = approp;
    }

    public String getApprop() {
        return approp;
    }

    public void discard() {
        // is there anything else to do here?
    }

    public String getConceptDocumentation() {
        return conceptDocumentation;
    }

    public List<String> getSlotDocumentation() {
        return slotDocumentation;
    }
}

==> renew2.6.1source.zip: renew2.6.1/src/FS/src/de/renew/formalism/fs/ShadowConcept.java <==
package de.renew.formalism.fs;

import de.renew.shadow.ShadowInscribable;
import de.renew.shadow.ShadowNet;

import java.util.List;


public class ShadowConcept extends ShadowInscribable {
    private String namespace;
    private String name;
    private String approp;
    private String conceptDocumentation;
    private List<String> slotDocumentation;
    private String conceptAnnotation;
    private List<String> slotAnnotation;
    private String stereotype;

    public ShadowConcept(ShadowNet net, String name, String approp,
                         String conceptDocumentation,
                         List<String> slotDocumentation,
                         String conceptAnnotation, List<String> slotAnnotation,
                         String stereotype) {
        super(net);
        int end = name.indexOf("::");
        if (end == -1) {
            namespace = net.getName();
            this.name = name;
        } else {
            namespace = name.substring(0, end);
            this.name = name.substring(end + 2);
        }
        this.approp = approp;
        this.conceptDocumentation = conceptDocumentation;
        this.slotDocumentation = slotDocumentation;
        this.conceptAnnotation = conceptAnnotation;
        this.slotAnnotation = slotAnnotation;
        this.stereotype = stereotype;
    }

    public String getName() {
        return name;
    }

    public String getNamespace() {
        return namespace;
    }

    public String getFullName() {
        return namespace + "::" + name;
    }

    public void setApprop(String approp) {
        this.approp = approp;
    }

    public String getApprop() {
        return approp;
    }

    @Override
    public void discard() {
        // is there anything else to do here?
    }

    public String getConceptDocumentation() {
        return conceptDocumentation;
    }

    public List<String> getSlotDocumentation() {
        return slotDocumentation;
    }

    public String getConceptAnnotation() {
        return conceptAnnotation;
    }

    public List<String> getSlotAnnotation() {
        return slotAnnotation;
    }

    public String getStereotype() {
        return stereotype;
    }
}
